
Lectures
========

.. contents::
    :local:

Données publiques
+++++++++++++++++

* `Données des urgences hospitalières et de SOS médecins relatives à l'épidémie de COVID-19
  <https://www.data.gouv.fr/fr/datasets/donnees-des-urgences-hospitalieres-et-de-sos-medecins-relatives-a-lepidemie-de-covid-19/>`_
  (open.data.gouv.fr)
* `COVID-19
  <https://github.com/CSSEGISandData/COVID-19>`_, données mise à jour quotidiennement
  reprenant les décomptes pour chaque pays
* `Données des urgences hospitalières et de SOS médecins relatives à l'épidémie de COVID-19
  <https://www.data.gouv.fr/fr/datasets/donnees-des-urgences-hospitalieres-et-de-sos-medecins-relatives-a-lepidemie-de-covid-19/>`_
* `Population par tranche d'âge et sexe (estimations localisées de population)
  <https://www.data.gouv.fr/fr/datasets/population-par-tranche-d-age-et-sexe-estimations-localisees-de-population/>`_
* `Densité de population (habitants au km2) 2016
  <https://www.observatoire-des-territoires.gouv.fr/outils/cartographie-interactive/#c=indicator&i=insee_rp_hist_1968.dens_pop&s=2016&view=map26>`_
* `Matrices de contacts française
  <https://figshare.com/articles/French_contact_matrices/1466918>`_
* `Data Drees
  <http://www.data.drees.sante.gouv.fr/ReportFolders/reportFolders.aspx?IF_ActivePath=P,432,433,707>`_

Lectures
++++++++

* `CODATA <https://www.collectif-codata.fr/note.pdf>`_
* `Un panorama des recherches contre le COVID-19 dans le domaine des sciences et technologie de l'information
  <https://github.com/StephaneCanu/covid_AI_resources/blob/master/GDR_ISIS_Covid_IA_2.pdf>`_
* `Estimating the asymptomatic proportion of coronavirus disease 2019 (COVID-19) cases on board the Diamond Princess cruise ship, Yokohama, Japan, 2020
  <https://www.eurosurveillance.org/content/10.2807/1560-7917.ES.2020.25.10.2000180>`_
* `Modélisation de l'épidémie de COVID-19
  <http://covid-ete.ouvaton.org/>`_
* `AI v Covid-19 <http://people.idsia.ch/~juergen/ai-covid.html>`_ (catalogue d'articles)
* `Inferring COVID-19 spreading rates and potential change points for case number forecasts
  <https://arxiv.org/abs/2004.01105>`_
  

Une série d'articles intéressants...

* `Coronavirus: Learning How to Dance (Part 1)
  <https://medium.com/@tomaspueyo/coronavirus-learning-how-to-dance-b8420170203e>`_
* `Coronavirus: The Basic Dance Steps Everybody Can Follow (Part 2)
  <https://medium.com/@tomaspueyo/coronavirus-learning-how-to-dance-b8420170203e>`_
* `Coronavirus: How to Do Testing and Contact Tracing (Part 3)
  <https://medium.com/@tomaspueyo/coronavirus-learning-how-to-dance-b8420170203e>`_
  
Et la critique que France Culture faisait de l'auteur le 16 mars 2020
sur son article
`Coronavirus : Agissez Aujourd'hui
<https://medium.com/tomas-pueyo/coronavirus-agissez-aujourdhui-2bd1dc7838f6>`_ :
`Coronavirus : une épidémie de faux articles scientifiques
<https://www.franceculture.fr/emissions/radiographies-du-coronavirus-la-chronique/radiographies-du-coronavirus-du-lundi-16-mars-2020>`_.

*Study*

* `MODELING COVID-19 IN THE UNITED STATES <https://covid19.gleamproject.org/>`_ (dashboard)
* `Effectiveness of social distancing strategies for protecting a community from a pandemic with a datadriven contact network based on census and real-world mobility data
  <https://covid-19-sds.github.io/assets/pdfs/Preliminary_Report_Effectiveness_of_social_distance_strategies_COVID-19.pdf>`_
* `Epidemiological characteristics of COVID-19 cases in Italy and estimates of the reproductive numbers one month into the epidemic
  <https://www.medrxiv.org/content/10.1101/2020.04.08.20056861v1.full.pdf>`_
* `Effectiveness of social distancing strategies for protecting a community from a pandemic with a data-driven contact network based on census and real-world mobility data
  <https://covid-19-sds.github.io/>`_
* `Mobile phone data and COVID-19: Missing an opportunity?
  <https://arxiv.org/ftp/arxiv/papers/2003/2003.12347.pdf>`_
* `Estimating the burden of SARS-CoV-2 in France
  <https://hal-pasteur.archives-ouvertes.fr/pasteur-02548181>`_
* `Experts envision two scenarios if the new coronavirus isn't contained
  <https://www.statnews.com/2020/02/04/two-scenarios-if-new-coronavirus-isnt-contained/>`_

*SIR*

* `MODELING PANDEMICS (3)
  <https://freakonometrics.hypotheses.org/60514>`_,
  modèle :epkg:`SIR` par Arthur Charpentier
* `Propagation of the SARS-CoV-2 coronavirus
  <https://github.com/gabriel-turinici/covid19/blob/master/sliadr_model_v11_HK_G_Turinici.ipynb>`_,
  modèle `SLIADRE <https://www.medrxiv.org/content/10.1101/2020.02.14.20022939v1>`_
* `COVID-19 dynamics with SIR model
  <https://www.lewuathe.com/covid-19-dynamics-with-sir-model.html>`_
* `Infectious Disease Modelling: Beyond the Basic SIR Model
  <https://towardsdatascience.com/infectious-disease-modelling-beyond-the-basic-sir-model-216369c584c4>`_

*R0*

* `The R0 package: a toolbox to estimate reproduction numbers for epidemic outbreaks
  <https://bmcmedinformdecismak.biomedcentral.com/track/pdf/10.1186/1472-6947-12-147>`_

*SIR + Kalman*

* `Infection Modeling — Part 1
  <https://towardsdatascience.com/infection-modeling-part-1-87e74645568a>`_
* `An Improved State Filter Algorithm for SIR Epidemic Forecasting
  <https://www.insight-centre.org/sites/default/files/publications/faia285-0524.pdf>`_
* `Ensemble Kalman Filter
  <https://en.wikipedia.org/wiki/Ensemble_Kalman_filter>`_,
  `Extended Kalman filter
  <https://en.wikipedia.org/wiki/Extended_Kalman_filter>`_
* `Data Assimilation Using an Ensemble Kalman Filter Technique
  <https://journals.ametsoc.org/doi/pdf/10.1175/1520-0493%281998%29126%3C0796%3ADAUAEK%3E2.0.CO%3B2>`_
* `Extended Kalman Filter: Why do we need an Extended Version?
  <https://towardsdatascience.com/extended-kalman-filter-43e52b16757d>`_
* `Ensemble Kalman Filtering without a Model
  <https://journals.aps.org/prx/pdf/10.1103/PhysRevX.6.011021>`_

*Simulation micro*

* `Measurability of the epidemic reproduction number in data-driven contact networks
  <https://www.pnas.org/content/pnas/115/50/12680.full.pdf>`_
* `Modelling the coronavirus epidemic in a city with Python
  <https://towardsdatascience.com/modelling-the-coronavirus-epidemic-spreading-in-a-city-with-python-babd14d82fa2>`_
* `A mathematical model for the spatiotemporal epidemic spreading of COVID19
  <https://covid-19-risk.github.io/map/model.pdf>`_
* `Modeling the spatial spread of infectious diseases: the GLobal Epidemic and Mobility computational model
  <https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3056392/pdf/nihms225903.pdf>`_,
  cet article contient notemment des matrices de contacts venant de l'article qui
  suit.
* `Using Data on Social Contacts to Estimate Age-specific Transmission Parameters for Respiratory-spread Infectious Agents
  <https://academic.oup.com/aje/article/164/10/936/162511>`_
* `Unifying Markov Chain Approach for Disease and Rumor Spreading in Complex Networks
  <https://arxiv.org/pdf/1609.00682.pdf>`_
* `Modèle CAST <https://blog.parcoor.com/2020-04-22-cast-prediction-propagation/>`_,
  `notebook <https://github.com/parcoor/py-propagsim/blob/master/examples/example0.ipynb>`_,
  `py-propagsim <https://github.com/parcoor/py-propagsim>`_

*Temporal Point Process*

* `COVID-19 machine learning projects at Max Planck Institute
  <https://ellis.eu/en/covid-19/talks/covid-19-machine-learning-projects-at-max-planck-institute>`_
* `Learning with Temporal Point Processes
  <http://learning.mpi-sws.org/tpp-icml18/>`_
* `An Introduction to Event History Analysis
  <https://spia.uga.edu/faculty_pages/rbakker/pols8501/OxfordOneNotes.pdf>`_
* `Survival and Event History Analysis, A Process Point of View
  <https://epdf.pub/survival-and-event-history-analysis-a-process-point-of-view.html>`_
* `An Introduction to the Theory of Point Processes, volume I, Elementary Theory and Methods, 2nd Edition
  <https://epdf.pub/an-introduction-to-the-theory-of-point-processes.html>`_
* `An Introduction to the Theory of Point Processes, volume II, General Thoery and Structure, 2nd Edition
  <https://epdf.pub/an-introduction-to-the-theory-of-point-processes-volume-ii-general-theory-and-st.html>`_

Modules
+++++++

* :epkg:`pyepydemic`, comme ce modules, il permet de simuler
  une épidémie mais il ne permet pas d'estimer les coefficients
  ce qui est l'objectif visé ici.
* `Mathematics of Epidemics on Networks
  <https://github.com/springer-math/Mathematics-of-Epidemics-on-Networks>`_,
  c'est autant un livre qu'un module.
  
Code
++++

* `Bayesian inference and forecast of COVID-19
  <https://github.com/Priesemann-Group/covid19_inference_forecast>`_
* `A Spatiotemporal Epidemic Model to Quantify The Effects of Testing, Contact Tracing and Containment
  <https://github.com/covid19-model/simulator>`_
